@@ -13,24 +13,25 @@ class Request:
         self.data = data
 
     def __repr__(self):
-        return f"<Request {self.host}:{self.port} {self.path} {len(self.data)}>"
+        return f"<Request {self.host} (port {self.port}) {self.path} {len(self.data)}>"
 
     def __str__(self):
-        return f"{self.host}:{self.port} {self.path} {len(self.data)}"
+        return f"{self.host} {self.path} {len(self.data)}"
 
     def send(self):
         sock = socket.create_connection((self.host, self.port))
-        host = f"{self.host}:{self.port}".encode("idna")
+        host = f"{self.host}".encode("idna")
         path = self.path.encode("ascii")
         sock.send(b"%s %s %d\r\n" % (host, path, len(self.data)))
         sock.send(self.data.encode("ascii"))
-        return Response(sock)
+        return Response(sock, self)
 
 
 class Response:
-    def __init__(self, socket: socket.socket):
+    def __init__(self, socket: socket.socket, request: Request = None):
         self.socket = socket
         self.file = self.socket.makefile(mode="rb")
+        self.request = request
 
         try:
             status, meta = self.file.readline(4096).split(maxsplit=1)
@@ -68,6 +69,10 @@ class Status:
 def get(url: str, data: str = ""):
     """Fetches url and returns a response object"""
     u = urllib.parse.urlparse(url)
+    if not u.hostname:
+        u = urllib.parse.urlparse("spartan://"+url)
+    if u.scheme != "spartan":
+        raise RuntimeError("Unsupported scheme")
     if u.query:  # Ignores data argument if query is in url
         data = u.query
     req = Request(u.hostname, u.port or 300, u.path or "/", data)
